Config

Struct Config 

#[non_exhaustive]
pub struct Config { /* private fields */ }
System configuration.

This struct is marked with #[non_exhaustive] and can’t be instantiated directly. This is done to prevent breaking changes when new fields are added to the struct. Instead, use the Config::default() method to create a new instance.

Examples

Default initialization

let peripherals = esp_hal::init(esp_hal::Config::default());

Custom initialization

use esp_hal::{clock::CpuClock, time::Duration};
let config = esp_hal::Config::default().with_cpu_clock(CpuClock::max());
let peripherals = esp_hal::init(config);

Implementations

Source

impl Config

pub fn with_cpu_clock(self, cpu_clock: impl Into<ClockConfig>) -> Self

Apply a clock configuration.

With the unstable feature enabled, this function accepts both ClockConfig and CpuClock.

pub fn cpu_clock(&self) -> CpuClock

👎Deprecated:

Use clock_config instead.

The CPU clock configuration preset.

Panics

This function will panic if the CPU clock configuration is not exactly one of the CpuClock presets.

pub fn clock_config(&self) -> ClockConfig

Available on crate feature unstable only.

The CPU clock configuration.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.